pub struct MockSendsApi {
SendsApi_expectations: MockSendsApi_SendsApi,
}Fields
SendsApi_expectations: MockSendsApi_SendsApiImplementations
Sourceimpl MockSendsApi
impl MockSendsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockSendsApi
impl MockSendsApi
Sourcepub fn expect_access(&mut self) -> &mut Expectation
pub fn expect_access(&mut self) -> &mut Expectation
Create an Expectation for mocking the access method
Sourcepub fn expect_access_using_auth(&mut self) -> &mut Expectation
pub fn expect_access_using_auth(&mut self) -> &mut Expectation
Create an Expectation for mocking the access_using_auth method
Sourcepub fn expect_azure_validate_file(&mut self) -> &mut Expectation
pub fn expect_azure_validate_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the azure_validate_file method
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_send_file_download_data(&mut self) -> &mut Expectation
pub fn expect_get_send_file_download_data(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_send_file_download_data method
Sourcepub fn expect_get_send_file_download_data_using_auth(
&mut self,
) -> &mut Expectation
pub fn expect_get_send_file_download_data_using_auth( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_send_file_download_data_using_auth method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_file(&mut self) -> &mut Expectation
pub fn expect_post_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_file method
Sourcepub fn expect_post_file_for_existing_send(&mut self) -> &mut Expectation
pub fn expect_post_file_for_existing_send(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_file_for_existing_send method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_put_remove_auth(&mut self) -> &mut Expectation
pub fn expect_put_remove_auth(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_remove_auth method
Sourcepub fn expect_put_remove_password(&mut self) -> &mut Expectation
pub fn expect_put_remove_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_remove_password method
Sourcepub fn expect_renew_file_upload(&mut self) -> &mut Expectation
pub fn expect_renew_file_upload(&mut self) -> &mut Expectation
Create an Expectation for mocking the renew_file_upload method